/*******************************************************************************
Filename:       hal_lcd.h

Autor:          Onur Kayikci
                Texas Instruments Freising, Germany
Datum:          19.11.2009

Description:    This file contains the interface to the LCD Service.

Processor:      MSP430F5529

*******************************************************************************/

#ifndef HAL_LCD_H
#define HAL_LCD_H

/**************************************************************************************************
 *                                          INCLUDES
 **************************************************************************************************/


/**************************************************************************************************
 *                                         CONSTANTS
 **************************************************************************************************/
/* These are the basic commands for the EA DOGXL160x-7  LCD   */

#define Set_Com_End_H                 0xF1
#define Set_Com_End_L                 0x67
#define Set_LCD_Mapping_Control       0xC0
#define Set_Scroll_Line_LSB           0x40
#define Set_Scroll_Line_MSB           0x50
#define Set_Panel_Loading             0x2B
#define Set_LCD_Bias_Ratio            0xEB
#define Set_Vbias_Potentiometer_H     0x81
#define Set_Vbias_Potentiometer_L     0x5F
#define Set_RAM_Address_Control       0x89
#define Set_Display_Enable            0xAF
#define Set_All_Pixels_On             0xA5
#define System_Reset                  0xE2
#define Page_Address                  0x60
#define Column_LSB0                   0x00
#define Column_MSB0                   0x10
#define CD                            0x10



/**************************************************************************************************
 *                                          MACROS
 **************************************************************************************************/


/**************************************************************************************************
 *                                         TYPEDEFS
 **************************************************************************************************/


/**************************************************************************************************
 *                                     GLOBAL VARIABLES
 **************************************************************************************************/


/**************************************************************************************************
 *                                     FUNCTIONS - API
 **************************************************************************************************/

/*
 * Initialize LCD Service
 */
extern void HalLcd_Init(void);

/*
 * Set all Pixels on the LCD
 */

extern void HalLcd_AllPixelsOn(void);

/*
 * System Reset of the LCD
 */

extern void HalLcd_Rst(void);

/*
 * Erase whole LCD RAM
 */

extern void HalLcd_Clean(void);

/*
 * Write a font to the LCD
 */

extern void HalLcd_Write(uint8 row, uint8 col, uint16 f );

/*
 * Write a string to the LCD
 */
extern void HalLcd_WriteString (uint8 y, uint8 x, char word[]);

/**************************************************************************************************
**************************************************************************************************/


#endif
